# PyMOSP

PyMOSP is a Python library to access [MOSP](https://github.com/CASES-LU/MOSP).


## Installation

```bash
$ pipx install PyMOSP
✨🐍✨
```

or via the Git repository:

```bash
$ git clone https://github.com/CASES-LU/PyMOSP
$ cd PyMOSP
$ poetry install
$ poetry run nose2 -v --pretty-assert
```


## Examples

See the examples in the file [example.py](example.py) or in the tests folder.


## License

This software is licensed under
[GNU General Public License version 3](https://www.gnu.org/licenses/gpl-3.0.html).

* Copyright (C) 2019-2021 Cédric Bonhomme
* Copyright (C) 2019-2021 SMILE gie securitymadein.lu

For more information, [the list of authors and contributors](AUTHORS.md)
is available.
